lustre/ui/styles
Functions
pub fn elements() -> Element(a)
Render a <style /> element that sets up the styles for all the elements
provided by this library. If you prefer, this stylesheet is also provided
as a static CSS file in the priv directory of this package.